@@ -22,13 +22,14 @@
 
 #include "pkg.h"
 
-Package *parse_package_file (const char *path, gboolean ignore_requires,
-			     gboolean ignore_private_libs,
-			     gboolean ignore_requires_private);
+Package *parse_package_file (const char *key, const char *path,
+                             gboolean ignore_requires,
+                             gboolean ignore_private_libs,
+                             gboolean ignore_requires_private);
 
-Package *get_compat_package (const char *name);
+GList   *parse_module_list (Package *pkg, const char *str, const char *path);
 
-GSList  *parse_module_list (Package *pkg, const char *str, const char *path);
+char    *parse_package_variable (Package *pkg, const char *variable);
 
 #endif
 
